import lodash from 'lodash'
// 千分位
export const formatqfw = (number) => {
  if (!number) {
    return ['--', '--']
  }
  number = parseFloat(number)
  if (typeof (number) !== 'number') {
    return ['--']
  }
  let val = ''
  let unit = ''
  if (number > 100000000) {
    unit = '亿'
    val = (number / 100000000).toFixed(2)
  } else if (number > 10000) {
    unit = '万'
    val = (number / 10000).toFixed(2)
  } else {
    unit = ''
    val = number
  }
  val = (val + '').replace(/\d{1,3}(?=(\d{3})+(\.\d*)?$)/g, '$&,')
  return { value: val, unit: unit }
}

/* 强制保留两位小数 */
export const toDecimal2 = (number) => {
  let f = parseFloat(number)
  if (isNaN(f)) {
    return '--'
  }
  f = Math.round(f * 100) / 100
  let s = f.toString()
  let rs = s.indexOf('.')
  if (rs < 0) {
    rs = s.length
    s += '.'
  }
  while (s.length <= rs + 2) {
    s += '0'
  }
  return s
}


export const findMaxDivisor = (objList, key) => {
  let maxObj = lodash.maxBy(objList, key)
  let divisor = 1
  let unit = ''
  if (maxObj[key] > 100000000) {
    divisor = 100000000
    unit = '亿'
  } else if (maxObj[key] > 10000) {
    divisor = 10000
    unit = '万'
  }
  return {
    divisor: divisor,
    unit: unit
  }
}

export default {
  formatqfw: formatqfw,
  toDecimal2: toDecimal2,
  findMaxDivisor: findMaxDivisor
}
